ymatrix.mnp.R is a function used to generate the response matrix
for the Multinomial Probit models.ymatrix.mnp(data, base=NULL, extra=FALSE, verbose=verbose)TRUE for generating the names for the coefficients as
well as the model matrix. The default is FALSE.TRUE, helpful messages
are printed on the screen. The default is FALSE.extra=TRUE, a list containing the following elements:TRUE for the Multinomial ordered Probit
model, and FALSE for the standard Multinomial Probit model.extra=FALSE, the response matrix will be returned.mprobit, xmatrix.mnp